Overall, there were 87 commits that closed 49 issues since our last release on 2025-01-31.

<a name="changes-by-package"></a>
## Changes by Package


<a name="libpysal-v4.13.0"></a>
### libpysal v4.13.0
* [#780:](https://github.com/pysal/libpysal/pull/780) BUG: ensure validity of polygons in voronoi_frames 
* [#769:](https://github.com/pysal/libpysal/issues/769) FutureWarning: Objects based on the `Geometry` class will deprecated and removed in a future version of libpysal 
* [#778:](https://github.com/pysal/libpysal/issues/778) pulp installation on apple silicon fails since pulp 3.0.0 
* [#777:](https://github.com/pysal/libpysal/pull/777) add union fallback to voronoi_frames 
* [#776:](https://github.com/pysal/libpysal/issues/776) GEOS induced topological error in voronoi_frames 
* [#774:](https://github.com/pysal/libpysal/issues/774) [Question]: Usage of Graph Algorithms and Any Slowdowns? 
* [#231:](https://github.com/pysal/libpysal/pull/231) move to splot implementation of gdf plotting 
* [#319:](https://github.com/pysal/libpysal/pull/319) standardizing libpysal/weights docs 

<a name="segregation-v2.5.2"></a>
### segregation v2.5.2
* [#236:](https://github.com/pysal/segregation/pull/236) use ax instead of plt 


<a name="momepy-v0.10.0"></a>
### momepy v0.10.0
* [#692:](https://github.com/pysal/momepy/pull/692) Add Python 3.13 to testing matrix 
* [#595:](https://github.com/pysal/momepy/pull/595) Simplify edges in enclosed_tessellation 
* [#688:](https://github.com/pysal/momepy/pull/688) The sunlight optimised indicator variable 
* [#687:](https://github.com/pysal/momepy/pull/687) ENH: allow passing kwargs to voronoi_frames in tessellation 
* [#685:](https://github.com/pysal/momepy/pull/685) DOC: fix the image link in lcustering example 
* [#697:](https://github.com/pysal/momepy/pull/697) ENH: add simplify keyword to morphological_tessellation 
* [#691:](https://github.com/pysal/momepy/issues/691) drop Python 3.10 from testing matrix 
* [#694:](https://github.com/pysal/momepy/pull/694) remove support for Python 3.10 - #691 
* [#690:](https://github.com/pysal/momepy/issues/690) Testing against Python 3.13 
* [#689:](https://github.com/pysal/momepy/pull/689) [pre-commit.ci] pre-commit autoupdate 
* [#447:](https://github.com/pysal/momepy/issues/447) keep line attributes in `remove_false_nodes` 
* [#682:](https://github.com/pysal/momepy/pull/682) Enhance remove_false_nodes Function: Retain Line Attributes and Expose aggfunc Parameter. 
* [#548:](https://github.com/pysal/momepy/issues/548) Follow-ups on consolidate_intersections 


<a name="spreg-v1.8.3"></a>
### spreg v1.8.3
* [#173:](https://github.com/pysal/spreg/pull/173) SciPy sparse array migration from sparse matrices 

<a name="mapclassify-v2.9.0"></a>
### mapclassify v2.9.0
* [#234:](https://github.com/pysal/mapclassify/pull/234) legendgram method 
* [#249:](https://github.com/pysal/mapclassify/pull/249) `ruff` - `/tests/*` & `docs/conf.py` 
* [#248:](https://github.com/pysal/mapclassify/issues/248) lint & format `/tests/*`, etc. 
* [#247:](https://github.com/pysal/mapclassify/pull/247) minimum Python 3.11 & updates min deps 
* [#238:](https://github.com/pysal/mapclassify/issues/238) SPEC000 – drop 3.9 & 3.10 + min deps 
* [#225:](https://github.com/pysal/mapclassify/issues/225) time to drop Python 3.9 support? 
* [#246:](https://github.com/pysal/mapclassify/pull/246) optional-deps section in `pyproject` --  `notebook` 
* [#245:](https://github.com/pysal/mapclassify/issues/245) incorrect install stipulation in `all` section of `pyproject.toml` 
* [#244:](https://github.com/pysal/mapclassify/issues/244) add a notebooks deps section to `pyproject.toml` 
* [#243:](https://github.com/pysal/mapclassify/issues/243) add `pyarrow` to deps for `notebooks/08_manual_coloring.ipynb` 
* [#241:](https://github.com/pysal/mapclassify/pull/241) add Python 313 into CI matrix - #239 
* [#239:](https://github.com/pysal/mapclassify/issues/239) Testing against Python 3.13 
* [#237:](https://github.com/pysal/mapclassify/pull/237) [pre-commit.ci] pre-commit autoupdate 
* [#236:](https://github.com/pysal/mapclassify/issues/236) [Question]: Usage of Graph Algorithms and Any Slowdowns? 


<a name="pysal-v25.07rc1"></a>
### pysal v25.07rc1
* [#1376:](https://github.com/pysal/pysal/issues/1376) `codecov` badge now needs token 
* [#1369:](https://github.com/pysal/pysal/issues/1369) Update GSoC 2025 Idea List 
* [#1371:](https://github.com/pysal/pysal/pull/1371) Correct pypi push action 
* [#1368:](https://github.com/pysal/pysal/pull/1368) add back docs deps in ci/312-latest 
* [#1367:](https://github.com/pysal/pysal/issues/1367) Build & Push Docs is failing 
* [#1366:](https://github.com/pysal/pysal/pull/1366) CI: new manual gh action for pypi release 

<a name="contributors"></a>
## Contributors

Many thanks to all of the following individuals who contributed to this release:


 - Dan Schult
 - Eli Knaap
 - James Gaboardi
 - Knaaptime
 - Krasen Samardzhiev
 - Martin Fleischmann
 - Pedro Amaral
 - Serge Rey
